==> bzr-2.0.3p0.tgz: lib/python2.5/site-packages/bzrlib/plugins/netrc_credential_store/__init__.py <==
# Copyright (C) 2008 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

"""Use ~/.netrc as a credential store for authentication.conf."""

# Since we are a built-in plugin we share the bzrlib version
from bzrlib import version_info

from bzrlib import (
    config,
    lazy_import,
    )

lazy_import.lazy_import(globals(), """
    import errno
    import netrc

    from bzrlib import (
        errors,
        )
""")


class NetrcCredentialStore(config.CredentialStore):

    def __init__(self):
        super(NetrcCredentialStore, self).__init__()
        try:
            self._netrc = netrc.netrc()
        except IOError, e:
            if e.args[0] == errno.ENOENT:
                raise errors.NoSuchFile(e.filename)
            else:
                raise

    def decode_password(self, credentials):
        auth = self._netrc.authenticators(credentials['host'])
        password = None
        if auth is not None:
            user, account, password = auth
            cred_user = credentials.get('user', None)
            if cred_user is None or user != cred_user:
                # We don't use the netrc ability to provide a user since there
                # is no way to give it back to AuthConfig. So if the user
                # doesn't match, we don't return a password.
                password = None
        return password


config.credential_store_registry.register_lazy(
    'netrc', __name__, 'NetrcCredentialStore', help=__doc__)


def load_tests(basic_tests, module, loader):
    testmod_names = [
        'tests',
        ]
    basic_tests.addTest(loader.loadTestsFromModuleNames(
            ["%s.%s" % (__name__, tmn) for tmn in testmod_names]))
    return basic_tests

==> bzr-2.4.2.tgz: lib/python2.7/site-packages/bzrlib/plugins/netrc_credential_store/__init__.py <==
# Copyright (C) 2008-2011 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

__doc__ = """Use ~/.netrc as a credential store for authentication.conf."""

# Since we are a built-in plugin we share the bzrlib version
from bzrlib import version_info

from bzrlib import (
    config,
    lazy_import,
    )

lazy_import.lazy_import(globals(), """
import errno
import netrc

from bzrlib import (
    errors,
    )
""")


class NetrcCredentialStore(config.CredentialStore):

    def __init__(self):
        super(NetrcCredentialStore, self).__init__()
        try:
            self._netrc = netrc.netrc()
        except IOError, e:
            if e.args[0] == errno.ENOENT:
                raise errors.NoSuchFile(e.filename)
            else:
                raise

    def decode_password(self, credentials):
        auth = self._netrc.authenticators(credentials['host'])
        password = None
        if auth is not None:
            user, account, password = auth
            cred_user = credentials.get('user', None)
            if cred_user is None or user != cred_user:
                # We don't use the netrc ability to provide a user since there
                # is no way to give it back to AuthConfig. So if the user
                # doesn't match, we don't return a password.
                password = None
        return password


config.credential_store_registry.register_lazy(
    'netrc', __name__, 'NetrcCredentialStore', help=__doc__)


def load_tests(basic_tests, module, loader):
    testmod_names = [
        'tests',
        ]
    basic_tests.addTest(loader.loadTestsFromModuleNames(
            ["%s.%s" % (__name__, tmn) for tmn in testmod_names]))
    return basic_tests
